package com.changhu.module.management.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.changhu.common.annotation.CheckUserType;
import com.changhu.common.annotation.JsonBody;
import com.changhu.common.annotation.UserType;
import com.changhu.common.pojo.vo.SelectNodeVo;
import com.changhu.enums.ClientType;
import com.changhu.module.management.pojo.params.SecurityUnitSaveOrUpdateParams;
import com.changhu.module.management.pojo.queryParams.SecurityUnitPagerQueryParams;
import com.changhu.module.management.pojo.vo.SecurityUnitPagerVo;
import com.changhu.module.management.service.SecurityUnitService;
import com.changhu.support.mybatisplus.pojo.params.PageParams;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.List;

/**
 * @author 20252
 * @createTime 2024/8/30 上午10:46
 * @desc SecurityUnitController...
 */
@Tag(name = "单位-保安")
@JsonBody
@RequestMapping("/securityUnit")
public class SecurityUnitController {

    @Autowired
    private SecurityUnitService securityUnitService;

    @Operation(summary = "分页查询")
    @PostMapping("/pager")
    public Page<SecurityUnitPagerVo> pager(@RequestBody PageParams<SecurityUnitPagerQueryParams, SecurityUnitPagerVo> queryParams) {
        return securityUnitService.pager(queryParams);
    }

    @Operation(summary = "新增或修改")
    @PostMapping("/saveOrUpdate")
    public void saveOrUpdate(@RequestBody @Valid SecurityUnitSaveOrUpdateParams params) {
        securityUnitService.saveOrUpdate(params);
    }

    @Operation(summary = "查询单位下的项目经理")
    @GetMapping("/listProjectManager")
    @CheckUserType(userTypes = UserType.MANAGEMENT_SECURITY)
    public List<SelectNodeVo<Long>> listProjectManager() {
        return securityUnitService.listProjectManager();
    }

}
