package com.changhu.module.management.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.lang.Dict;
import cn.hutool.core.lang.func.LambdaUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.changhu.common.db.enums.IsEnable;
import com.changhu.common.db.enums.MiniProgramUserIdentity;
import com.changhu.common.pojo.vo.SelectNodeVo;
import com.changhu.common.utils.UserUtil;
import com.changhu.module.miniProgram.mapper.MiniProgramUserMapper;
import com.changhu.module.management.mapper.SecurityUnitMapper;
import com.changhu.module.miniProgram.pojo.entity.MiniProgramUser;
import com.changhu.module.management.pojo.entity.SecurityUnit;
import com.changhu.module.management.pojo.params.SecurityUnitSaveOrUpdateParams;
import com.changhu.module.management.pojo.queryParams.SecurityUnitPagerQueryParams;
import com.changhu.module.management.pojo.vo.SecurityUnitPagerVo;
import com.changhu.module.management.service.SecurityUnitService;
import com.changhu.support.mybatisplus.pojo.params.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

/**
 * security_unit (保安单位)  服务实现类
 * author: luozhun
 * desc 由groovy脚本自动生成
 */
@Service
public class SecurityUnitServiceImpl extends ServiceImpl<SecurityUnitMapper, SecurityUnit> implements SecurityUnitService {

    @Autowired
    private MiniProgramUserMapper miniProgramUserMapper;

    @Override
    public Page<SecurityUnitPagerVo> pager(PageParams<SecurityUnitPagerQueryParams, SecurityUnitPagerVo> queryParams) {
        return baseMapper.pager(queryParams.getPage(), queryParams.getParams());
    }

    @Override
    public void saveOrUpdate(SecurityUnitSaveOrUpdateParams params) {
        SecurityUnit securityUnit = BeanUtil.copyProperties(params, SecurityUnit.class);
        Optional.ofNullable(params.getAdministrativeDivisionCodes())
                .ifPresent(codes -> {
                    if (!codes.isEmpty()) {
                        securityUnit.setProvince(codes.get(0));
                    }
                    if (codes.size() >= 2) {
                        securityUnit.setCity(codes.get(1));
                    }
                    if (codes.size() >= 3) {
                        securityUnit.setDistricts(codes.get(2));
                    }
                    if (codes.size() >= 4) {
                        securityUnit.setStreet(codes.get(3));
                    }
                });
        this.saveOrUpdate(securityUnit);
    }

    @Override
    public List<SelectNodeVo<Long>> listProjectManager() {
        String tel = LambdaUtil.getFieldName(MiniProgramUser::getTelephone);
        String sex = LambdaUtil.getFieldName(MiniProgramUser::getSex);
        return miniProgramUserMapper.selectList(Wrappers.<MiniProgramUser>lambdaQuery()
                        .eq(MiniProgramUser::getIsEnable, IsEnable.TRUE)
                        .eq(MiniProgramUser::getIdentity, MiniProgramUserIdentity.PROJECT_MANAGER)
                        .eq(MiniProgramUser::getUnitId, UserUtil.getUnitId()))
                .stream()
                .map(item -> SelectNodeVo.<Long>builder()
                        .value(item.getSnowFlakeId())
                        .label(item.getName())
                        .extData(Dict.of(
                                tel, item.getTelephone(),
                                sex, item.getSex()
                        ))
                        .build())
                .toList();
    }

}
